@@ -17,6 +17,6 @@
 #' 
 #' @importFrom utils capture.output
 kableone <- function(x, ...) {
-  capture.output(x <- print(x))
+  capture.output(x <- print(x, ...))
   knitr::kable(x, ...)
-}
\ No newline at end of file
+}
